==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp5/krb5_SUSE-SU-2022_4335-1_sles_12.5.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for krb5 SUSE-SU-2022:4335-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2022-December/013194.html
# Source:      Security Announcement Generator (sagen.py) v2.0.6
# Modified:    2023 Jun 13
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "krb5"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2022-December/013194.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = False
	name = 'krb5'
	main = ''
	severity = 'Important'
	tag = 'SUSE-SU-2022:4335-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 12):
		if ( server['DistroPatchLevel'] == 5 ):
			packages = {
				'krb5': '1.12.5-40.43.1',
				'krb5-client': '1.12.5-40.43.1',
				'krb5-client-debuginfo': '1.12.5-40.43.1',
				'krb5-debuginfo': '1.12.5-40.43.1',
				'krb5-debugsource': '1.12.5-40.43.1',
				'krb5-doc': '1.12.5-40.43.1',
				'krb5-plugin-kdb-ldap': '1.12.5-40.43.1',
				'krb5-plugin-kdb-ldap-debuginfo': '1.12.5-40.43.1',
				'krb5-plugin-preauth-otp': '1.12.5-40.43.1',
				'krb5-plugin-preauth-otp-debuginfo': '1.12.5-40.43.1',
				'krb5-plugin-preauth-pkinit': '1.12.5-40.43.1',
				'krb5-plugin-preauth-pkinit-debuginfo': '1.12.5-40.43.1',
				'krb5-server': '1.12.5-40.43.1',
				'krb5-server-debuginfo': '1.12.5-40.43.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp5/krb5_SUSE-SU-2023_3398-1_sles_12.5.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for krb5 SUSE-SU-2023:3398-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2023-August/016010.html
# Source:      Security Announcement Generator (sagen.py) v2.0.13
# Modified:    2023 Aug 31
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "krb5"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2023-August/016010.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = False
	name = 'krb5'
	main = ''
	severity = 'Important'
	tag = 'SUSE-SU-2023:3398-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 12):
		if ( server['DistroPatchLevel'] == 5 ):
			packages = {
				'krb5': '1.12.5-40.52.1',
				'krb5-client': '1.12.5-40.52.1',
				'krb5-client-debuginfo': '1.12.5-40.52.1',
				'krb5-debuginfo': '1.12.5-40.52.1',
				'krb5-debugsource': '1.12.5-40.52.1',
				'krb5-doc': '1.12.5-40.52.1',
				'krb5-plugin-kdb-ldap': '1.12.5-40.52.1',
				'krb5-plugin-kdb-ldap-debuginfo': '1.12.5-40.52.1',
				'krb5-plugin-preauth-otp': '1.12.5-40.52.1',
				'krb5-plugin-preauth-otp-debuginfo': '1.12.5-40.52.1',
				'krb5-plugin-preauth-pkinit': '1.12.5-40.52.1',
				'krb5-plugin-preauth-pkinit-debuginfo': '1.12.5-40.52.1',
				'krb5-server': '1.12.5-40.52.1',
				'krb5-server-debuginfo': '1.12.5-40.52.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()
